SoundVolumeView class

Properties

applicationDevices List<Device>
applicationDevices You only get the application devices
getter/setter pair
captureDevices List<Device>
captureDevices You only get the capture devices
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
outputDevices List<Device>
outputDevices You only get the output devices
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shell ↔ Shell
shell ProcessRun Shell
latefinal
stateController StreamController<SoundVolumeViewState>
stateController A StreamController that emits the state of the SoundVolumeView
final

Methods

checkIfSoundVolumeViewInstalled() Future<bool>
checkIfSoundVolumeViewInstalled checks if SoundVolumeView is installed in the system
installSoundVolumeView() Future<bool>
installSoundVolumeView installs SoundVolumeView in the system
mute(Device device) Future<bool>
mute mute the device
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
platformSupported() bool
SoundVolumeView only working on Windows
refreshDevices() Future<List<Device>>
refreshDevices refreshDevices gets all input, output, and application devices
setAppDefault(Device applicationDevice, Device outputDevice, {DefaultType defaultType = DefaultType.multimedia}) Future<bool>
setAppDefault Allows you to set the default render/capture device for specfic application.
setDefault(Device outputDevice, {DefaultType defaultType = DefaultType.all}) Future<bool>
setDefault Output devices set all default types (Console, Multimedia, and Communications)
setListenToThisDevice(Device device, {bool listen = true}) Future<bool>
setListenToThisDevice Enable or disable recording line preview
setPlaybackThroughDevice(Device recordingDevice, Device playbackDevice) Future<bool>
setPlaybackThroughDevice Assigns the output device to the recording line signal
setVolume(Device device, int volume) Future<bool>
setVolume Will lower or raise the volume to the indicated device - 0% to 100%
toString() String
A string representation of this object.
inherited
uninstallSoundVolumeView() Future<bool>
uninstallSoundVolumeView uninstalls SoundVolumeView in the system
unMute(Device device) Future<bool>
unMute Turn on device sound

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getInstance() SoundVolumeView
getInstance Get the singleton instance of SoundVolumeView